@@ -4,4 +4,9 @@ from models import ConfigFile
 from utils import ConfigGroup, autodiscover
 from context import config_context
 
+
+__all__ = ("VERSION", "ConfigFile", "ConfigGroup",
+           "autodiscover", "config_context", )
+
+
 VERSION = (0, 1, 7)
